// Copyright (C) 2019  Wilko Manger
//
// This file is part of matrix-dart-sdk.
//
// matrix-dart-sdk is free software: you can redistribute it and/or modify
// it under the terms of the GNU Affero General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// matrix-dart-sdk is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU Affero General Public License for more details.
//
// You should have received a copy of the GNU Affero General Public License
// along with matrix-dart-sdk.  If not, see <https://www.gnu.org/licenses/>.

import 'package:validators/validators.dart';

/// Helper for parsing an URL (not Uri).
abstract class Url {

  static const _protocols = [
    'http',
    'https',
    'ftp',
    'mxc'
  ];

  /// Parse [Uri], requiring that is an URL, not just an [Uri].
  ///
  /// Will accept `mxc` URLs.
  ///
  /// Note that the returned type is still an [Uri], but guaranteed
  /// that it's an URL.
  static Uri parse(String url) {
    if (!isURL(url, protocols: _protocols)) {
      throw FormatException('Not a valid url: $url}');
    }

    return Uri.parse(url);
  }
}

/// True if [input] is an URL, false otherwise.
///
/// [input] can be an [Uri] or [String].
bool isUrl(dynamic input) {
  var str;
  if (input is Uri) {
    str = input.toString();
  } else if (input is String) {
    str = input;
  }

  // input was neither Uri nor String
  if (str == null) {
    return false;
  } else {
    return isURL(input.toString(), protocols: Url._protocols);
  }
}